@@ -42,6 +42,23 @@ typedef struct {
 /* FIXME: Refactor this code to remove the need of those globals */
 static WebKitSettings *webkit_settings = NULL;
 static GFileMonitor *user_style_sheet_monitor = NULL;
+static WebKitUserStyleSheet *style_sheet = NULL;
+static GList *ucm_list = NULL;
+
+static void
+update_user_style_on_all_ucm (void)
+{
+  GList *list = NULL;
+
+  for (list = ucm_list; list != NULL; list = list->next) {
+    WebKitUserContentManager *ucm = list->data;
+
+    if (style_sheet)
+      webkit_user_content_manager_add_style_sheet (ucm, style_sheet);
+    else
+      webkit_user_content_manager_remove_all_style_sheets (ucm);
+  }
+}
 
 static void
 user_style_sheet_output_stream_splice_cb (GOutputStream *output_stream,
@@ -52,14 +69,13 @@ user_style_sheet_output_stream_splice_cb (GOutputStream *output_stream,
 
   bytes = g_output_stream_splice_finish (output_stream, result, NULL);
   if (bytes > 0) {
-    WebKitUserStyleSheet *style_sheet;
+    g_clear_pointer (&style_sheet, webkit_user_style_sheet_unref);
 
     style_sheet = webkit_user_style_sheet_new (g_memory_output_stream_get_data (G_MEMORY_OUTPUT_STREAM (output_stream)),
                                                WEBKIT_USER_CONTENT_INJECT_ALL_FRAMES, WEBKIT_USER_STYLE_LEVEL_USER,
                                                NULL, NULL);
-    webkit_user_content_manager_add_style_sheet (WEBKIT_USER_CONTENT_MANAGER (ephy_embed_shell_get_user_content_manager (ephy_embed_shell_get_default ())),
-                                                 style_sheet);
-    webkit_user_style_sheet_unref (style_sheet);
+
+    update_user_style_on_all_ucm ();
   }
 }
 
@@ -95,8 +111,6 @@ user_style_sheet_file_changed (GFileMonitor      *monitor,
                                gpointer           user_data)
 {
   if (event_type == G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT) {
-    webkit_user_content_manager_remove_all_style_sheets (WEBKIT_USER_CONTENT_MANAGER (ephy_embed_shell_get_user_content_manager (ephy_embed_shell_get_default ())));
-
     g_file_read_async (file, G_PRIORITY_DEFAULT, NULL,
                        (GAsyncReadyCallback)user_style_sheet_read_cb, NULL);
   }
@@ -113,7 +127,9 @@ webkit_pref_callback_user_stylesheet (GSettings  *settings,
 
   if (!value) {
     g_clear_object (&user_style_sheet_monitor);
-    webkit_user_content_manager_remove_all_style_sheets (WEBKIT_USER_CONTENT_MANAGER (ephy_embed_shell_get_user_content_manager (ephy_embed_shell_get_default ())));
+    g_clear_pointer (&style_sheet, webkit_user_style_sheet_unref);
+
+    update_user_style_on_all_ucm ();
   } else {
     GFile *file;
     GError *error = NULL;
@@ -551,3 +567,22 @@ ephy_embed_prefs_get_settings (void)
 
   return g_once (&once_init, ephy_embed_prefs_init, NULL);
 }
+
+void
+ephy_embed_prefs_apply_user_style (WebKitUserContentManager *ucm)
+{
+  if (style_sheet)
+    webkit_user_content_manager_add_style_sheet (ucm, style_sheet);
+}
+
+void
+ephy_embed_prefs_register_ucm (WebKitUserContentManager *ucm)
+{
+  ucm_list = g_list_append (ucm_list, ucm);
+}
+
+void
+ephy_embed_prefs_unregister_ucm (WebKitUserContentManager *ucm)
+{
+  ucm_list = g_list_remove (ucm_list, ucm);
+}
