@@ -147,7 +147,6 @@ ephy_embed_shell_get_extension_proxy_for_page_id (EphyEmbedShell *self,
 static GList *
 tabs_catalog_get_tabs_info (EphyTabsCatalog *catalog)
 {
-  EphyEmbedShell *embed_shell = EPHY_EMBED_SHELL (catalog);
   WebKitFaviconDatabase *database;
   GList *windows;
   g_autoptr (GList) tabs = NULL;
@@ -156,6 +155,8 @@ tabs_catalog_get_tabs_info (EphyTabsCatalog *catalog)
   const char *url;
   g_autofree char *favicon = NULL;
 
+  g_assert ((gpointer)catalog == (gpointer)embed_shell);
+
   windows = gtk_application_get_windows (GTK_APPLICATION (embed_shell));
   database = webkit_web_context_get_favicon_database (ephy_embed_shell_get_web_context (embed_shell));
 
@@ -225,16 +226,16 @@ web_process_extension_password_form_focused_message_received_cb (WebKitUserConte
                                                                  EphyEmbedShell           *shell)
 {
   guint64 page_id;
-  gboolean insecure_action;
+  gboolean insecure_form_action;
   g_autoptr (GVariant) variant = NULL;
   g_autofree char *message_str = NULL;
 
   message_str = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
   variant = g_variant_parse (G_VARIANT_TYPE ("(tb)"), message_str, NULL, NULL, NULL);
 
-  g_variant_get (variant, "(tb)", &page_id, &insecure_action);
+  g_variant_get (variant, "(tb)", &page_id, &insecure_form_action);
   g_signal_emit (shell, signals[PASSWORD_FORM_FOCUSED], 0,
-                 page_id, insecure_action);
+                 page_id, insecure_form_action);
 }
 
 static void
@@ -905,32 +906,6 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
     webkit_uri_scheme_request_finish_error (request, error);
 }
 
-static void
-ftp_request_cb (WebKitURISchemeRequest *request)
-{
-  g_autoptr (GDesktopAppInfo) app_info = NULL;
-  g_autoptr (GList) list = NULL;
-  g_autoptr (GError) error = NULL;
-  const char *uri;
-
-  uri = webkit_uri_scheme_request_get_uri (request);
-  g_app_info_launch_default_for_uri (uri, NULL, &error);
-
-  if (!error) {
-    g_signal_emit_by_name (webkit_uri_scheme_request_get_web_view (request), "close", NULL);
-    return;
-  }
-
-  /* Default URI handler didn't work. Try nautilus before giving up. */
-  app_info = g_desktop_app_info_new ("org.gnome.Nautilus.desktop");
-  list = g_list_append (list, (gpointer)uri);
-
-  if (app_info && g_app_info_launch_uris (G_APP_INFO (app_info), list, NULL, NULL))
-    g_signal_emit_by_name (webkit_uri_scheme_request_get_web_view (request), "close", NULL);
-  else
-    webkit_uri_scheme_request_finish_error (request, error);
-}
-
 static void
 initialize_web_process_extensions (WebKitWebContext *web_context,
                                    EphyEmbedShell   *shell)
@@ -1205,11 +1180,6 @@ ephy_embed_shell_startup (GApplication *application)
                                           (WebKitURISchemeRequestCallback)ephy_resource_request_cb,
                                           NULL, NULL);
 
-  /* No support for FTP, try to open in nautilus instead of failing */
-  webkit_web_context_register_uri_scheme (priv->web_context, "ftp",
-                                          (WebKitURISchemeRequestCallback)ftp_request_cb,
-                                          NULL, NULL);
-
   /* Store cookies in moz-compatible SQLite format */
   cookie_manager = webkit_web_context_get_cookie_manager (priv->web_context);
   if (!webkit_web_context_is_ephemeral (priv->web_context)) {
