@@ -124,7 +124,6 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
 
   has_web_scheme = !(g_ascii_strncasecmp (address, "http", colonpos) &&
                      g_ascii_strncasecmp (address, "https", colonpos) &&
-                     g_ascii_strncasecmp (address, "ftp", colonpos) &&
                      g_ascii_strncasecmp (address, "file", colonpos) &&
                      g_ascii_strncasecmp (address, "javascript", colonpos) &&
                      g_ascii_strncasecmp (address, "data", colonpos) &&
@@ -133,7 +132,8 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-source", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
-                     g_ascii_strncasecmp (address, "inspector", colonpos));
+                     g_ascii_strncasecmp (address, "inspector", colonpos) &&
+                     g_ascii_strncasecmp (address, "webkit", colonpos));
 
   return has_web_scheme;
 }
@@ -141,8 +141,19 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
 gboolean
 ephy_embed_utils_address_is_existing_absolute_filename (const char *address)
 {
-  return g_path_is_absolute (address) &&
-         g_file_test (address, G_FILE_TEST_EXISTS);
+  g_autofree char *real_address = NULL;
+
+  if (!strchr (address, '#')) {
+    real_address = g_strdup (address);
+  } else {
+    gint pos;
+
+    pos = g_strstr_len (address, -1, "#") - address;
+    real_address = g_strndup (address, pos);
+  }
+
+  return g_path_is_absolute (real_address) &&
+         g_file_test (real_address, G_FILE_TEST_EXISTS);
 }
 
 static gboolean
@@ -200,6 +211,18 @@ is_bang_search (const char *address)
   return FALSE;
 }
 
+static gboolean
+is_host_with_port (const char *address)
+{
+  g_auto (GStrv) split = g_strsplit (address, ":", -1);
+  gint64 port = 0;
+
+  if (g_strv_length (split) == 2)
+    port = g_ascii_strtoll (split[1], NULL, 10);
+
+  return port != 0;
+}
+
 gboolean
 ephy_embed_utils_address_is_valid (const char *address)
 {
@@ -221,7 +244,8 @@ ephy_embed_utils_address_is_valid (const char *address)
            ephy_embed_utils_address_is_existing_absolute_filename (address) ||
            g_regex_match (get_non_search_regex (), address, 0, NULL) ||
            is_public_domain (address) ||
-           is_bang_search (address);
+           is_bang_search (address) ||
+           is_host_with_port (address);
 
   g_clear_object (&info);
 
@@ -248,11 +272,14 @@ ephy_embed_utils_normalize_address (const char *address)
   if (ephy_embed_utils_address_is_existing_absolute_filename (address))
     return g_strconcat ("file://", address, NULL);
 
+  if (strcmp (address, "about:gpu") == 0)
+    return g_strdup ("webkit://gpu");
+
   if (g_str_has_prefix (address, "about:") && strcmp (address, "about:blank"))
     return g_strconcat (EPHY_ABOUT_SCHEME, address + strlen ("about"), NULL);
 
   if (!ephy_embed_utils_address_has_web_scheme (address)) {
-    SoupURI *uri;
+    g_autoptr (SoupURI) uri = NULL;
 
     uri = soup_uri_new (address);
 
@@ -265,12 +292,10 @@ ephy_embed_utils_normalize_address (const char *address)
      * handler for the scheme, and since we'll fail for localhost
      * and IP, we'd fallback to loading it as a domain. */
     if (!uri ||
-        (uri && !g_strcmp0 (uri->scheme, "localhost")) ||
-        (uri && g_hostname_is_ip_address (uri->scheme)))
+        !g_strcmp0 (uri->scheme, "localhost") ||
+        g_hostname_is_ip_address (uri->scheme) ||
+        is_host_with_port (address))
       effective_address = g_strconcat ("http://", address, NULL);
-
-    if (uri)
-      soup_uri_free (uri);
   }
 
   return effective_address ? effective_address : g_strdup (address);
