@@ -103,13 +103,12 @@ Ephy.getWebAppIcon = function(baseURL)
 
 Ephy.PreFillUserMenu = class PreFillUserMenu
 {
-    constructor(manager, formAuth, users)
+    constructor(manager, userElement, users, passwordElement)
     {
         this._manager = manager;
-        this._formAuth = formAuth;
-        this._userElement = formAuth.usernameNode;
+        this._userElement = userElement;
         this._users = users;
-        this._passwordElement = formAuth.passwordNode;
+        this._passwordElement = passwordElement;
         this._selected = null;
         this._wasEdited = false;
 
@@ -166,7 +165,7 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
         if (newSelect) {
             this._selected = newSelect;
             this._userElement.value = this._selected.firstElementChild.textContent;
-            this._usernameSelected();
+            this._manager.preFill();
         } else {
             this._passwordElement.value = '';
         }
@@ -187,14 +186,13 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
             'z-index: 2147483647;' +
             'cursor: default;' +
             'background-color: white;' +
-            'box-shadow: 5px 5px 5px rgba(0,0,0,0.2);' +
+            'box-shadow: 5px 5px 5px black;' +
             'border-top: 0px;' +
             'border-radius: 8px;' +
-            'padding: 12px 0px;' +
             '-webkit-user-modify: read-only ! important;';
-        mainDiv.style.width = this._userElement.offsetWidth + 'px';
-        mainDiv.style.left = elementRect.left + document.body.scrollLeft + 'px';
-        mainDiv.style.top = elementRect.top + elementRect.height + document.body.scrollTop + 'px';
+        mainDiv.style.width = this._userElement.offsetWidth;
+        mainDiv.style.left = elementRect.left + document.body.scrollLeft;
+        mainDiv.style.top = elementRect.top + document.body.scrollTop;
 
         let ul = document.createElement('ul');
         ul.style.cssText = 'margin: 0; padding: 0;';
@@ -211,7 +209,6 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
             li.style.cssText = 'list-style-type: none ! important;' +
                 'background-image: none ! important;' +
                 'padding: 3px 6px ! important;' +
-                'color: black;' +
                 'margin: 0px;';
             // FIXME: selection colors.
             li.tabindex = -1;
@@ -224,7 +221,6 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
             anchor.style.cssText = 'font-weight: normal ! important;' +
                 'font-family: sans ! important;' +
                 'text-decoration: none ! important;' +
-                'color: black;' +
                 '-webkit-user-modify: read-only ! important;';
             // FIXME: selection colors.
             anchor.textContent = user;
@@ -234,7 +230,7 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
                 this._userElement.value = user;
                 this._selected = li;
                 this._removeMenu();
-                this._usernameSelected();
+                this._manager.preFill();
             }, true);
         }
 
@@ -250,13 +246,6 @@ Ephy.PreFillUserMenu = class PreFillUserMenu
         if (menu)
             menu.parentNode.removeChild(menu);
     }
-
-    _usernameSelected()
-    {
-        this._formAuth.username = this._userElement.value;
-        this._passwordElement.value = '';
-        this._manager.preFill(this._formAuth);
-    }
 }
 
 Ephy.formControlsAssociated = function(pageID, frameID, forms, serializer)
@@ -343,7 +332,9 @@ Ephy.PasswordManager = class PasswordManager
     {
         let element = this._takePendingPromise(id);
         if (element) {
-            if (password)
+            if (username === '')
+                username = null;
+            if (password !== '')
                 element.resolver({username, password});
             else
                 element.resolver(null);
@@ -454,7 +445,7 @@ Ephy.FormManager = class FormManager
             Ephy.passwordManager.queryUsernames(formAuth.origin).then(users => {
                 if (users.length > 1) {
                     Ephy.log('More than one saved username, hooking menu for choosing which one to select');
-                    this._preFillUserMenu = new Ephy.PreFillUserMenu(this, formAuth, users);
+                    this._preFillUserMenu = new Ephy.PreFillUserMenu(this, formAuth.usernameNode, users, formAuth.passwordNode);
                 }
                 this.preFill(formAuth);
             });
@@ -571,13 +562,19 @@ Ephy.FormManager = class FormManager
 
     _passwordFormFocused(event)
     {
-        let isInsecureAction = false;
+        let isFormActionInsecure = false;
         if (this._form.action) {
             let url = new URL(this._form.action);
-            // Warning: we do not whitelist localhost because it could be redirected by DNS.
-            isInsecureAction = url.protocol == 'http:' && url.hostname != "127.0.0.1" && url.hostname != "::1";
+            if (url.protocol == 'http:') {
+                // We trust localhost to be local since glib!616.
+                let parts = url.hostname.split('.');
+                if (parts.length > 0) {
+                    let tld = parts[parts.length - 1];
+                    isFormActionInsecure = tld != "127.0.0.1" && tld != "::1" && tld != "localhost";
+                }
+            }
         }
-        window.webkit.messageHandlers.passwordFormFocused.postMessage(this._passwordFormMessageSerializer(this._frameID, isInsecureAction));
+        window.webkit.messageHandlers.passwordFormFocused.postMessage(this._passwordFormMessageSerializer(this._frameID, isFormActionInsecure));
     }
 
     _findPasswordFields()
