@@ -38,7 +38,6 @@ struct _EphyBookmarksPopover {
   GtkWidget *bookmarks_list_box;
   GtkWidget *tags_list_box;
   GtkWidget *tag_detail_list_box;
-  GtkWidget *tag_detail_back_button;
   GtkWidget *tag_detail_label;
   char *tag_detail_tag;
 
@@ -240,10 +239,11 @@ create_tag_row (const char *tag)
 
   if (g_strcmp0 (tag, EPHY_BOOKMARKS_FAVORITES_TAG) == 0) {
     image = gtk_image_new_from_icon_name ("emblem-favorite-symbolic", GTK_ICON_SIZE_MENU);
+    label = gtk_label_new (_(EPHY_BOOKMARKS_FAVORITES_TAG));
   } else {
     image = gtk_image_new_from_icon_name ("ephy-bookmark-tag-symbolic", GTK_ICON_SIZE_MENU);
+    label = gtk_label_new (tag);
   }
-  label = gtk_label_new (tag);
 
   gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, FALSE, 0);
@@ -410,7 +410,10 @@ ephy_bookmarks_popover_show_tag_detail (EphyBookmarksPopover *self,
     gtk_container_add (GTK_CONTAINER (self->tag_detail_list_box), row);
   }
 
-  gtk_label_set_label (GTK_LABEL (self->tag_detail_label), tag);
+  if (strcmp (tag, EPHY_BOOKMARKS_FAVORITES_TAG) == 0)
+    gtk_label_set_label (GTK_LABEL (self->tag_detail_label), _(EPHY_BOOKMARKS_FAVORITES_TAG));
+  else
+    gtk_label_set_label (GTK_LABEL (self->tag_detail_label), tag);
 
   gtk_stack_set_visible_child_name (GTK_STACK (self->toplevel_stack), "tag_detail");
 
@@ -421,6 +424,26 @@ ephy_bookmarks_popover_show_tag_detail (EphyBookmarksPopover *self,
   g_sequence_free (bookmarks);
 }
 
+static void
+ephy_bookmarks_popover_open_bookmark (EphyBookmarksPopover *self,
+                                      GtkListBoxRow        *row)
+{
+  GtkWidget *window;
+  GActionGroup *action_group;
+  GAction *action;
+  const char *url;
+
+  window = gtk_widget_get_ancestor (GTK_WIDGET (self), EPHY_TYPE_WINDOW);
+  g_assert (EPHY_IS_WINDOW (window));
+  action_group = gtk_widget_get_action_group (window, "win");
+  g_assert (action_group != NULL);
+  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "open-bookmark");
+  g_assert (action != NULL);
+  url = ephy_bookmark_row_get_bookmark_url (EPHY_BOOKMARK_ROW (row));
+
+  g_action_activate (action, g_variant_new_string (url));
+}
+
 static void
 ephy_bookmarks_popover_list_box_row_activated_cb (EphyBookmarksPopover *self,
                                                   GtkListBoxRow        *row,
@@ -435,26 +458,29 @@ ephy_bookmarks_popover_list_box_row_activated_cb (EphyBookmarksPopover *self,
 
   type = g_object_get_data (G_OBJECT (row), "type");
   if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0) {
-    GtkWidget *window;
-    GActionGroup *action_group;
-    GAction *action;
-    const char *url;
-
-    window = gtk_widget_get_ancestor (GTK_WIDGET (self), EPHY_TYPE_WINDOW);
-    g_assert (EPHY_IS_WINDOW (window));
-    action_group = gtk_widget_get_action_group (window, "win");
-    g_assert (action_group != NULL);
-    action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "open-bookmark");
-    g_assert (action != NULL);
-    url = ephy_bookmark_row_get_bookmark_url (EPHY_BOOKMARK_ROW (row));
-
-    g_action_activate (action, g_variant_new_string (url));
+    ephy_bookmarks_popover_open_bookmark (self, row);
   } else {
     tag = g_object_get_data (G_OBJECT (row), "title");
     ephy_bookmarks_popover_show_tag_detail (self, tag);
   }
 }
 
+static gboolean
+ephy_bookmarks_popover_list_box_button_release_event_cb (EphyBookmarksPopover *self,
+                                                         GdkEvent             *event,
+                                                         GtkListBox           *box)
+{
+  GdkEventButton *event_button = (GdkEventButton *)event;
+  GtkListBoxRow *row = gtk_list_box_get_row_at_y (box, event_button->y);
+
+  if (event_button->button != GDK_BUTTON_MIDDLE)
+    return GDK_EVENT_PROPAGATE;
+
+  ephy_bookmarks_popover_open_bookmark (self, row);
+
+  return GDK_EVENT_STOP;
+}
+
 static void
 ephy_bookmarks_popover_finalize (GObject *object)
 {
@@ -478,7 +504,6 @@ ephy_bookmarks_popover_class_init (EphyBookmarksPopoverClass *klass)
   gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, bookmarks_list_box);
   gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, tags_list_box);
   gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, tag_detail_list_box);
-  gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, tag_detail_back_button);
   gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, tag_detail_label);
 }
 
@@ -573,6 +598,9 @@ ephy_bookmarks_popover_init (EphyBookmarksPopover *self)
   g_signal_connect_object (self->tag_detail_list_box, "row-activated",
                            G_CALLBACK (ephy_bookmarks_popover_list_box_row_activated_cb),
                            self, G_CONNECT_SWAPPED);
+  g_signal_connect_object (self->bookmarks_list_box, "button-release-event",
+                           G_CALLBACK (ephy_bookmarks_popover_list_box_button_release_event_cb),
+                           self, G_CONNECT_SWAPPED);
 }
 
 EphyBookmarksPopover *
