@@ -95,7 +95,6 @@ download_added_cb (EphyDownloadsManager *manager,
   }
 
   add_attention (action_bar_end);
-  gtk_widget_set_visible (action_bar_end->downloads_revealer, TRUE);
   gtk_revealer_set_reveal_child (GTK_REVEALER (action_bar_end->downloads_revealer), TRUE);
   gtk_widget_queue_draw (action_bar_end->downloads_image);
 
@@ -198,10 +197,8 @@ download_removed_cb (EphyDownloadsManager *manager,
                      EphyDownload         *download,
                      EphyActionBarEnd     *action_bar_end)
 {
-  if (!ephy_downloads_manager_get_downloads (manager)) {
-    gtk_widget_set_visible (action_bar_end->downloads_revealer, FALSE);
+  if (!ephy_downloads_manager_get_downloads (manager))
     gtk_revealer_set_reveal_child (GTK_REVEALER (action_bar_end->downloads_revealer), FALSE);
-  }
 }
 
 static void
@@ -255,7 +252,6 @@ ephy_action_bar_end_init (EphyActionBarEnd *action_bar_end)
   /* Downloads */
   downloads_manager = ephy_embed_shell_get_downloads_manager (ephy_embed_shell_get_default ());
 
-  gtk_widget_set_visible (action_bar_end->downloads_revealer, ephy_downloads_manager_get_downloads (downloads_manager) != NULL);
   gtk_revealer_set_reveal_child (GTK_REVEALER (action_bar_end->downloads_revealer),
                                  ephy_downloads_manager_get_downloads (downloads_manager) != NULL);
 
@@ -306,3 +302,9 @@ ephy_action_bar_end_get_bookmarks_button (EphyActionBarEnd *action_bar_end)
 {
   return action_bar_end->bookmarks_button;
 }
+
+GtkWidget *
+ephy_action_bar_end_get_downloads_revealer (EphyActionBarEnd *action_bar_end)
+{
+  return action_bar_end->downloads_revealer;
+}
