@@ -33,6 +33,7 @@ struct _EphySuggestionModel {
   GObject parent;
   EphyHistoryService *history_service;
   EphyBookmarksManager *bookmarks_manager;
+  GSequence *urls;
   GSequence *items;
   GCancellable *icon_cancellable;
 };
@@ -58,6 +59,7 @@ ephy_suggestion_model_finalize (GObject *object)
 
   g_clear_object (&self->bookmarks_manager);
   g_clear_object (&self->history_service);
+  g_clear_pointer (&self->urls, g_sequence_free);
   g_clear_pointer (&self->items, g_sequence_free);
 
   g_cancellable_cancel (self->icon_cancellable);
@@ -249,6 +251,7 @@ static guint
 add_bookmarks (EphySuggestionModel *self,
                const char          *query)
 {
+  g_autoptr (GList) new_urls = NULL;
   GSequence *bookmarks;
   guint added = 0;
 
@@ -265,6 +268,10 @@ add_bookmarks (EphySuggestionModel *self,
     url = ephy_bookmark_get_url (bookmark);
     title = ephy_bookmark_get_title (bookmark);
 
+    if (g_sequence_lookup (self->urls, (gpointer)url, (GCompareDataFunc)g_strcmp0,
+                           NULL))
+      continue;
+
     if (strlen (title) == 0)
       title = url;
 
@@ -278,11 +285,16 @@ add_bookmarks (EphySuggestionModel *self,
       suggestion = ephy_suggestion_new (markup, title, url);
       load_favicon (self, suggestion, url);
 
+      new_urls = g_list_prepend (new_urls, g_strdup (url));
       g_sequence_append (self->items, suggestion);
       added++;
     }
   }
 
+  for (GList *p = new_urls; p != NULL; p = p->next)
+    g_sequence_append (self->urls, g_steal_pointer (&p->data));
+  g_sequence_sort (self->urls, (GCompareDataFunc)g_strcmp0, NULL);
+
   return added;
 }
 
@@ -300,6 +312,10 @@ add_history (EphySuggestionModel *self,
     g_autofree gchar *markup = NULL;
     const gchar *title = url->title;
 
+    if (g_sequence_lookup (self->urls, url->url, (GCompareDataFunc)g_strcmp0,
+                           NULL))
+      continue;
+
     if (strlen (url->title) == 0)
       title = url->url;
 
@@ -339,7 +355,7 @@ add_search_engines (EphySuggestionModel *self,
     address = ephy_search_engine_manager_build_search_address (manager, engines[i], query);
     escaped_title = g_markup_escape_text (engines[i], -1);
     markup = dzl_fuzzy_highlight (escaped_title, query, FALSE);
-    suggestion = ephy_suggestion_new_without_subtitle (markup, engines[i], address);
+    suggestion = ephy_suggestion_new (markup, engines[i], address);
 
     uri = soup_uri_new (address);
     if (uri) {
@@ -388,6 +404,7 @@ add_tabs (EphySuggestionModel *self,
     g_autofree gchar *escaped_title = NULL;
     g_autofree gchar *markup = NULL;
     const gchar *display_address;
+    const gchar *url;
     g_autofree gchar *address = NULL;
     const gchar *title;
     g_autofree gchar *title_casefold = NULL;
@@ -400,13 +417,16 @@ add_tabs (EphySuggestionModel *self,
     embed = EPHY_EMBED (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), i));
     webview = ephy_embed_get_web_view (embed);
     display_address = ephy_web_view_get_display_address (webview);
+    url = ephy_web_view_get_address (webview);
     address = g_strdup_printf ("ephy-tab://%d", i);
     title = webkit_web_view_get_title (WEBKIT_WEB_VIEW (webview));
 
     display_address_casefold = g_utf8_casefold (display_address, -1);
     query_casefold = g_utf8_casefold (query, -1);
-    if (title)
-      title_casefold = g_utf8_casefold (title, -1);
+    if (!title)
+      title = "";
+
+    title_casefold = g_utf8_casefold (title, -1);
 
     if ((title_casefold && strstr (title_casefold, query_casefold)) || strstr (display_address_casefold, query_casefold)) {
       escaped_title = g_markup_escape_text (title, -1);
@@ -414,11 +434,14 @@ add_tabs (EphySuggestionModel *self,
       suggestion = ephy_suggestion_new_with_custom_subtitle (markup, title, _("Switch to Tab"), address);
       load_favicon (self, suggestion, display_address);
 
+      g_sequence_append (self->urls, g_strdup (url));
       g_sequence_append (self->items, suggestion);
       added++;
     }
   }
 
+  g_sequence_sort (self->urls, (GCompareDataFunc)g_strcmp0, NULL);
+
   return added;
 }
 
@@ -446,6 +469,8 @@ query_completed_cb (EphyHistoryService *service,
 
   removed = g_sequence_get_length (self->items);
 
+  g_clear_pointer (&self->urls, g_sequence_free);
+  self->urls = g_sequence_new (g_free);
   g_clear_pointer (&self->items, g_sequence_free);
   self->items = g_sequence_new (g_object_unref);
 
