@@ -95,7 +95,6 @@ struct _PrefsDialog {
   GtkWidget *restore_session_switch;
   GtkWidget *popups_allow_switch;
   GtkWidget *adblock_allow_switch;
-  GtkWidget *enable_plugins_checkbutton;
   GtkWidget *enable_safe_browsing_switch;
   GtkWidget *enable_smooth_scrolling_switch;
   GtkWidget *enable_mouse_gesture_switch;
@@ -140,7 +139,6 @@ struct _PrefsDialog {
   GtkWidget *sync_firefox_iframe_label;
   GtkWidget *sync_firefox_account_box;
   GtkWidget *sync_firefox_account_row;
-  GtkWidget *sync_sign_out_button;
   GtkWidget *sync_options_box;
   GtkWidget *sync_bookmarks_checkbutton;
   GtkWidget *sync_passwords_checkbutton;
@@ -1019,7 +1017,6 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_firefox_iframe_label);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_firefox_account_box);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_firefox_account_row);
-  gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_sign_out_button);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_options_box);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_bookmarks_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_passwords_checkbutton);
@@ -2026,9 +2023,9 @@ reader_font_style_get_name (HdyEnumValueObject *value,
 
   switch (hdy_enum_value_object_get_value (value)) {
     case EPHY_PREFS_READER_FONT_STYLE_SANS:
-      return g_strdup (_("Sans"));
+      return g_strdup (N_("Sans"));
     case EPHY_PREFS_READER_FONT_STYLE_SERIF:
-      return g_strdup (_("Serif"));
+      return g_strdup (N_("Serif"));
     default:
       return NULL;
   }
@@ -2072,9 +2069,9 @@ reader_color_scheme_get_name (HdyEnumValueObject *value,
 
   switch (hdy_enum_value_object_get_value (value)) {
     case EPHY_PREFS_READER_COLORS_LIGHT:
-      return g_strdup (_("Light"));
+      return g_strdup (N_("Light"));
     case EPHY_PREFS_READER_COLORS_DARK:
-      return g_strdup (_("Dark"));
+      return g_strdup (N_("Dark"));
     default:
       return NULL;
   }
